@@ -6,10 +6,11 @@ import warnings
 from tempfile import NamedTemporaryFile
 from functools import lru_cache
 
-import appdirs
-
-
-CACHE_DIR = appdirs.user_cache_dir('gpstime')
+try:
+    from platformdirs import user_cache_dir
+except ImportError:
+    from appdirs import user_cache_dir
+CACHE_DIR = user_cache_dir('gpstime')
 
 LEAP_FILES = [
     '/usr/share/zoneinfo/leap-seconds.list',
